==> desmume_0.6.0.orig.tar.gz: desmume-0.6.0/src/gtk-glade/globals.h <==
/* globals.h - this file is part of DeSmuME
 *
 * Copyright (C) 2007 Damien Nozay (damdoum)
 * Author: damdoum at users.sourceforge.net
 *
 * This file is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This file is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GLOBALS_H__
#define __GLOBALS_H__

#ifndef GTK_UI
#define GTK_UI
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
//#include <libgen.h>
#include <unistd.h>

#include <SDL.h>
#include <gtk/gtk.h>
#include <gdk/gdkkeysyms.h>
#include <glade/glade.h>

#include "../MMU.h"
#include "../registers.h"
#include "../armcpu.h"
#include "../NDSSystem.h"
#include "../cflash.h"
#include "../sndsdl.h"
#include "../ctrlssdl.h"
#include "../types.h"
#include "../saves.h"
#include "desmume.h"

int Frameskip;
u16 Keypad_Temp[NB_KEYS];

/* main.c */
GtkWidget * pWindow;
GtkWidget * pDrawingArea;
GtkWidget * pDrawingArea2;
GladeXML  * xml, * xml_tools;

typedef void (*VoidFunPtr)();
void notify_Tools();
void register_Tool(VoidFunPtr fun);
void unregister_Tool(VoidFunPtr fun);

/* callbacks.c */
void enable_rom_features();

/* callbacks_IO.c */
int ScreenCoeff_Size;
gboolean ScreenRotate;
gboolean ScreenRight;
gboolean ScreenGap;

void black_screen ();
void edit_controls();
void init_joy_labels();

/* printscreen.c */
int WriteBMP(const char *filename,u16 *bmp);

/* keyvalnames.c   -see <gdk/gdkkeysyms.h>- */
char * KEYVAL_NAMES[0x10000];
char * KEYNAME(int k);
void init_keyvals();

#endif /* __GLOBALS_H__ */

==> desmume_0.8.orig.tar.gz: desmume-0.8/src/gtk-glade/globals.h <==
/* globals.h - this file is part of DeSmuME
 *
 * Copyright (C) 2007 Damien Nozay (damdoum)
 * Author: damdoum at users.sourceforge.net
 *
 * This file is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This file is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GLOBALS_H__
#define __GLOBALS_H__

#ifndef GTK_UI
#define GTK_UI
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
//#include <libgen.h>
#include <unistd.h>

// Localization
#include <libintl.h>
#define _(String) gettext (String)

//#include <SDL/SDL.h>
// more portable
#include "SDL.h"

// fix gtk-glade on windows with no configure
#ifndef DATADIR
#define DATADIR " "
#endif
#ifndef GLADEUI_UNINSTALLED_DIR
#define GLADEUI_UNINSTALLED_DIR "glade/"
#endif

#include <gtk/gtk.h>
#include <gdk/gdkkeysyms.h>
#include <glade/glade.h>
#include <glade/glade-xml.h>


typedef union _callback_arg{
	gpointer      my_pointer;
	gconstpointer my_constpointer;
	
	gfloat   my_float;
	gdouble  my_double;
	gsize    my_size;
	gssize   my_ssize;
	
	gboolean my_boolean;

	guchar   my_uchar;
	guint    my_uint;
	guint8   my_uint8;
	guint16  my_uint16;
	guint32  my_uint32;
	guint64  my_uint64;
	gushort  my_ushort;
	gulong   my_ulong;

	gchar    my_char;
	gint     my_int;
	gint8    my_int8;
	gint16   my_int16;
	gint32   my_int32;
	gint64   my_int64;
	gshort   my_short;
	glong    my_long;	
} callback_arg;
#define dyn_CAST(gtype,var) (((callback_arg*)var)->my_##gtype)

#include "../MMU.h"
#include "../registers.h"
#include "../armcpu.h"
#include "../NDSSystem.h"
#include "../cflash.h"
#include "../sndsdl.h"
#include "../ctrlssdl.h"
#include "../types.h"
#include "../saves.h"
#include "../gl_vertex.h"
#include "../render3D.h"
#include "desmume.h"
#include "gdk_gl.h"

// autoconnect with strings as user_data

void
glade_xml_signal_autoconnect_StringObject (GladeXML *self);

//---

int Frameskip;
u16 Keypad_Temp[NB_KEYS];

/* main.c */
GtkWidget * pWindow;
GtkWidget * pDrawingArea, * pDrawingArea2;
GladeXML  * xml, * xml_tools;

typedef void (*VoidFunPtr)();
void notify_Tools();
void register_Tool(VoidFunPtr fun);
void unregister_Tool(VoidFunPtr fun);
gchar * get_ui_file (const char *filename);

/* callbacks.c */
void enable_rom_features();
void resize (float Size1, float Size2);
void rotate(float angle);
gboolean ScreenInvert;
gboolean ScreenGap;
gboolean ScreenRight;

/* callbacks_IO.c */
float ScreenCoeff_Size[2];
float ScreenRotate;

void black_screen ();
void edit_controls();
void init_joy_labels();

/* printscreen.c */
int WriteBMP(const char *filename,u16 *bmp);

/* keyvalnames.c   -see <gdk/gdkkeysyms.h>- */
char * KEYVAL_NAMES[0x10000];
char * KEYNAME(int k);
void init_keyvals();

#endif /* __GLOBALS_H__ */
